aboutsummaryrefslogtreecommitdiffstats
path: root/src/ArchiveFile.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'src/ArchiveFile.hxx')
-rw-r--r--src/ArchiveFile.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ArchiveFile.hxx b/src/ArchiveFile.hxx
index b771409b7..4bdba62ab 100644
--- a/src/ArchiveFile.hxx
+++ b/src/ArchiveFile.hxx
@@ -46,13 +46,13 @@ public:
virtual void Visit(ArchiveVisitor &visitor) = 0;
/**
* Opens an input_stream of a file within the archive.
*
* @param path the path within the archive
*/
- virtual input_stream *OpenStream(const char *path,
- Mutex &mutex, Cond &cond,
- Error &error) = 0;
+ virtual InputStream *OpenStream(const char *path,
+ Mutex &mutex, Cond &cond,
+ Error &error) = 0;
};
#endif
@@ -46,13 +46,13 @@ public:
virtual void Visit(ArchiveVisitor &visitor) = 0;
/**
- * Opens an input_stream of a file within the archive.
+ * Opens an InputStream of a file within the archive.
*
* @param path the path within the archive